GOV-Kennung SCHERGJO54EJ
Name

- Schönberg

Typ

- Hauptort Quelle Seite 110 Quelle Seite 92

Einwohner

- 3483 (1961-06-06) Quelle Seite 110
- 3574 (1970-05-27) Quelle Seite 92

Postleitzahl

- W2306 (- 1993-06-30)
- 24217 (1993-07-01 -)

externe Kennung

- geonames:2836925

Karte

TK25: 1628

- Bing
- Google Earth (KML)
- Google Maps
- MapQuest
- OpenStreetMap
- OpenStreetMap.de
- Virtuelles Kartenforum
- wikimapia

Zugehörigkeit
Übergeordnete Objekte

Probstei ( Landschaft)

Schönberg (St. Ansgar) ( Expositur Pfarrkuratie Pfarrei)

Schönberg ( Kirchspiel Kirchengemeinde) Quelle Quelle

Schönberg ( Gemeinde) Quelle Quelle Quelle

Untergeordnete Objekte

Name | Typ | GOV-Kennung | Zeitraum
--- | --- | --- | ---
Ev. Kirche/Schönberg, Schönberg |
             Kirche
| object_185252 |
Schönberg (St. Ansgar) |
             Kirche
| object_1187746 |